@@ -12,18 +12,28 @@
 ##############################################################################
 database_type='Firebird'
 
-from db import DB
-import sys, DABase
-import Shared.DC.ZRDB.Connection, ThreadLock
-from App.special_dtml import HTMLFile
-from zExceptions import BadRequest
+import sys
+from _thread import allocate_lock
 
-_Connection=Shared.DC.ZRDB.Connection.Connection
+from .db import DB
+import Shared.DC.ZRDB.Connection
+from App.special_dtml import HTMLFile
 
 _connections={}
-_connections_lock=ThreadLock.allocate_lock()
+_connections_lock=allocate_lock()
+
 
 addConnectionForm=HTMLFile('dtml/connectionAdd',globals())
+
+
+def manage_addFirebirdConnectionForm(self, REQUEST, *args, **kw):
+    """Add a connection form"""
+    return addConnectionForm(
+        self, self, REQUEST,
+        database_type=database_type,
+    )
+
+
 def manage_addFirebirdConnection(
     self, id, title, connection, check=None, REQUEST=None):
     """Add a DB connection to a folder"""
@@ -34,12 +44,12 @@ def manage_addFirebirdConnection(
         id, title, connection, check))
     if REQUEST is not None: return self.manage_main(self,REQUEST)
 
-class Connection(DABase.Connection):
+class Connection(Shared.DC.ZRDB.Connection.Connection):
     " "
     database_type=database_type
     id='%s_database_connection' % database_type
     meta_type=title='%s Database Connection' % database_type
-    icon='misc_/%sDA/conn.gif' % database_type
+    zmi_icon = 'fas fa-database'
 
     manage_properties=HTMLFile('dtml/connectionEdit', globals())
 
@@ -48,24 +58,6 @@ class Connection(DABase.Connection):
             return self._v_database_connection.opened
         return ''
 
-    def title_and_id(self):
-        s=_Connection.inheritedAttribute('title_and_id')(self)
-        if (hasattr(self, '_v_database_connection') and
-            self._v_database_connection.opened):
-            s="%s, which is connected" % s
-        else:
-            s="%s, which is <font color=red> not connected</font>" % s
-        return s
-
-    def title_or_id(self):
-        s=_Connection.inheritedAttribute('title_and_id')(self)
-        if (hasattr(self, '_v_database_connection') and
-            self._v_database_connection.opened):
-            s="%s (connected)" % s
-        else:
-            s="%s (<font color=red> not connected</font>)" % s
-        return s
-
     def connect(self,s):
         _connections_lock.acquire()
         try:
